#nvpl_scalapack-config.cmake
#
# Exported VARIABLES
#  * NVPL_BLACS_MPI_INTERFACES - List of available MPI Interface libs
#  * NVPL_SCALAPACK_INT_TYPES - List of available integer ABIs
#
# Interface targets
#  * nvpl::blacs_<int>_<mpi>
#      - BLACS interface where
#          <int> is from NVPL_SCALAPACK_INT_TYPES
#          <mpi> is from NVPL_BLACS_MPI_INTERFACES
#
#  * nvpl::scalapack_<int>
#       - ScaLAPACK library where
#           <int> is from NVPL_SCALAPACK_INT_TYPES


set(nvpl_scalapack_VERSION "0.1.0")
# build: 156


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was PackageConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

include(CMakeFindDependencyMacro)
if(NOT nvpl_blas_FOUND)
    find_dependency(nvpl_blas)
endif()
if(NOT nvpl_lapack_FOUND)
    find_dependency(nvpl_lapack)
endif()

include("${CMAKE_CURRENT_LIST_DIR}/nvpl_scalapack-targets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/nvpl_scalapack-static-targets.cmake" OPTIONAL)

# Allow Alias to targets
set(NVPL_SCALAPACK_INT_TYPES lp64;ilp64)
set(NVPL_BLACS_MPI_INTERFACES mpich;openmpi3;openmpi4;openmpi5)

foreach(_int IN LISTS NVPL_SCALAPACK_INT_TYPES)
    foreach(_mpi IN LISTS NVPL_BLACS_MPI_INTERFACES)
        if(NOT TARGET nvpl::blacs_${_int}_${_mpi})
            set_target_properties(nvpl_blacs_${_int}_${_mpi} PROPERTIES IMPORTED_GLOBAL 1)
            add_library(nvpl::blacs_${_int}_${_mpi} ALIAS nvpl_blacs_${_int}_${_mpi})
        endif()
    endforeach()
    if(NOT TARGET nvpl::scalapack_${_int})
        set_target_properties(nvpl_scalapack_${_int} PROPERTIES IMPORTED_GLOBAL 1)
        add_library(nvpl::scalapack_${_int} ALIAS nvpl_scalapack_${_int})
    endif()
endforeach()
unset(_int)
unset(_mpi)

get_target_property(nvpl_scalapack_LOCATION nvpl_scalapack_lp64 LOCATION)
get_filename_component(nvpl_scalapack_LOCATION ${nvpl_scalapack_LOCATION} DIRECTORY)
get_filename_component(nvpl_scalapack_LOCATION ${nvpl_scalapack_LOCATION}/.. REALPATH)

check_required_components(nvpl_scalapack)
message(STATUS
"Found nvpl_scalapack: (Location: ${nvpl_scalapack_LOCATION}\n\
                          Version: ${nvpl_scalapack_VERSION}\n\
                          IntTypes: ${NVPL_SCALAPACK_INT_TYPES}\n\
                          MpiInterfaces: ${NVPL_BLACS_MPI_INTERFACES})")
